@@ -1,6 +1,6 @@
 package Perinci::Sub::GetArgs::Array;
 
-use 5.010;
+use 5.010001;
 use strict;
 use warnings;
 use Log::Any '$log';
@@ -12,7 +12,7 @@ use Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(get_args_from_array);
 
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 our %SPEC;
 
@@ -46,7 +46,7 @@ _
             schema => ['array*' => {}],
             req => 1,
         },
-        spec => {
+        meta => {
             schema => ['hash*' => {}],
             req => 1,
         },
@@ -56,7 +56,7 @@ _
             description => <<'_',
 
 If set to 1, then if there are array elements unassigned to one of the arguments
-(due to missing 'arg_pos', for example), instead of generating an error, the
+(due to missing 'pos', for example), instead of generating an error, the
 function will just ignore them.
 
 _
@@ -118,16 +118,19 @@ sub get_args_from_array {
 1;
 #ABSTRACT: Get subroutine arguments from array
 
+__END__
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Perinci::Sub::GetArgs::Array - Get subroutine arguments from array
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -137,8 +140,8 @@ version 0.09
 
 =head1 DESCRIPTION
 
-This module provides get_args_from_array() (and gencode_get_args_from_array(),
-upcoming). This module is used by, among others, L<Perinci::Sub::GetArgs::Argv>.
+This module provides get_args_from_array(). This module is used by, among
+others, L<Perinci::Sub::GetArgs::Argv>.
 
 This module uses L<Log::Any> for logging framework.
 
@@ -148,6 +151,52 @@ This module has L<Rinci> metadata.
 
 None are exported by default, but they are exportable.
 
+
+None are exported by default, but they are exportable.
+
+=head2 get_args_from_array(%args) -> [status, msg, result, meta]
+
+Using information in metadata's 'args' property (particularly the 'pos' and
+'greedy' arg type clauses), extract arguments from an array into a hash
+\%args, suitable for passing into subs.
+
+Example:
+
+    my $meta = {
+        v => 1.1,
+        summary => 'Multiply 2 numbers (a & b)',
+        args => {
+            a => {schema=>'num*', pos=>0},
+            b => {schema=>'num*', pos=>1},
+        }
+    }
+
+then 'getI<args>from_array(array=>[2, 3], meta=>$meta)' will produce:
+
+    [200, "OK", {a=>2, b=>3}]
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<allow_extra_elems> => I<bool> (default: 0)
+
+Allow extra/unassigned elements in array.
+
+If set to 1, then if there are array elements unassigned to one of the arguments
+(due to missing 'pos', for example), instead of generating an error, the
+function will just ignore them.
+
+=item * B<array>* => I<array>
+
+=item * B<meta>* => I<hash>
+
+=back
+
+Return value:
+
+Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
+
 =head1 TODO
 
 I am not particularly happy with the duplication of functionality between this
@@ -164,13 +213,9 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2013 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
